@@ -1,4 +1,6 @@
+import csv
 import string
+import datetime
 from math import ceil
 from operator import itemgetter
 
@@ -479,8 +481,8 @@ class ModelResults:
             mae = median_absolute_error(y_test, y_predicted)
             r2 = r2_score(y_test, y_predicted)
 
-            print(f"Mean Negative Root Mean Squared Errror: {mse}")
-            print(f"Mean Negative Median Absolute Error: {mae}")
+            print(f"Mean Negative Root Mean Squared Errror: {(mse ** 5) * -1}")
+            print(f"Mean Negative Median Absolute Error: {mae * -1}")
             print(f"Mean R2: {r2}")
 
         return full_pipeline, y_predicted
